@echo off
set "GOROOT=%CONDA_BACKUP_GOROOT%"
set "CONDA_BACKUP_GOROOT="

set "CGO_ENABLED=%CONDA_BACKUP_CGO_ENABLED%"
set "CONDA_BACKUP_CGO_ENABLED="

set "CGO_CFLAGS=%CONDA_BACKUP_CGO_CFLAGS%"
set "CONDA_BACKUP_CGO_CFLAGS="

set "CGO_CPPFLAGS=%CONDA_BACKUP_CGO_CPPFLAGS%"
set "CONDA_BACKUP_CGO_CPPFLAGS="

set "CGO_CXXFLAGS=%CONDA_BACKUP_CGO_CXXFLAGS%"
set "CONDA_BACKUP_CGO_CXXFLAGS="

set "CGO_FFLAGS=%CONDA_BACKUP_CGO_FFLAGS%"
set "CONDA_BACKUP_CGO_FFLAGS="

set "CGO_LDFLAGS=%CONDA_BACKUP_CGO_LDFLAGS%"
set "CONDA_BACKUP_CGO_LDFLAGS="

