@echo off
if "%CONDA_BUILD%x"=="1x" (
  set "GOPATH=%CONDA_BACKUP_GOPATH%"
  set "CONDA_BACKUP_GOPATH="

  set "GOBIN=%CONDA_BACKUP_GOBIN%"
  set "CONDA_BACKUP_GOBIN="
)

set "GOOS=%CONDA_BACKUP_GOOS%"
set "CONDA_BACKUP_GOOS="

set "GOARCH=%CONDA_BACKUP_GOARCH%"
set "CONDA_BACKUP_GOARCH="
